import React from "react";
import { CollapsibleTabViewProps } from "react-native-collapsible-tab-view";
import { MaterialTopTabNavigationOptions } from "@react-navigation/material-top-tabs";
/**
 * A collapsible tab view that can be used as a Layout Route.
 *
 * Example in Layout Route:
 *
 * ```js
 * // app/(tabs)/_layout.tsx
 *
 * import { StyleSheet, Text, View } from "react-native";
 * import { TopTabs } from "../../etc/collapsible";
 *
 * export default function CustomLayout() {
 *   return (
 *     <TopTabs>
 *       <TopTabs.Header>
 *         <View pointerEvents="none" style={{ ... }}>
 *           <Text>Header</Text>
 *         </View>
 *       </TopTabs.Header>
 *
 *       <TopTabs.Screen name="index" />
 *     </TopTabs>
 *   );
 * }
 * ```
 *
 * Usage in child routes:
 *
 * ```js
 * // app/(tabs)/index.tsx
 *
 * import { Animated, StyleSheet, Text } from "react-native";
 * import { useScrollProps } from "../../etc/collapsible";
 *
 * export default function Screen() {
 *   const props = useScrollProps();
 *
 *   return (
 *     <Animated.ScrollView {...props}>
 *       // ...
 *     </Animated.ScrollView>
 *   );
 * }
 * ```
 * @param param0
 * @returns
 */
export declare const TopTabs: {
    ({ children, options, ...props }: {
        children?: React.ReactNode;
        screenOptions?: MaterialTopTabNavigationOptions;
        options?: Partial<CollapsibleTabViewProps<any>>;
    }): JSX.Element | null;
    Screen: typeof import("expo-router/build/views/Screen").Screen;
    Header: typeof Header;
};
declare function Header({ children }: {
    children: any;
}): any;
/** Get the scroll props for a child route of a collapsible tabs layout route. */
export declare function useScrollProps(): import("react-native-collapsible-tab-view").CollapsibleScenePropsAndRef;
export {};
//# sourceMappingURL=index.d.ts.map